if [ -z ${CONDA_BUILD+x} ]; then
    source /var/folders/nz/j6p8yfhx1mv_0grj5xl4650h0000gp/T/abs_5d4snxrbzv/croot/hatch-jupyter-builder_1683742845174/work/build_env_setup.sh
fi
/var/folders/nz/j6p8yfhx1mv_0grj5xl4650h0000gp/T/abs_5d4snxrbzv/croot/hatch-jupyter-builder_1683742845174/_h_env_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_pl/bin/python -m pip install --no-deps --no-build-isolation . -vv